from setuptools import setup


setup(name='metakernel_echo',
      version='0.19.1',
      description='A simple echo kernel for Jupyter/IPython',
      long_description='A simple echo kernel for Jupyter/IPython, based on MetaKernel',
      url='https://github.com/calysto/metakernel/tree/master/metakernel_echo',
      author='Douglas Blank',
      author_email='doug.blank@gmail.com',
      py_modules=['metakernel_echo'],
      install_requires=['metakernel'],
      classifiers = [
          'Framework :: IPython',
          'License :: OSI Approved :: BSD License',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 2',
          'Topic :: System :: Shells',
      ]
)



from Graphics import *
from Myro import show

# positive to left
def dragon(arrow, level=4, size=200, direction=45):
    if level:
        arrow.rotate(direction)
        dragon(arrow, level-1, size/1.41421356237, 45)
        arrow.rotate(-direction * 2)
        dragon(arrow, level-1, size/1.41421356237, -45)
        arrow.rotate(direction)
    else:
        arrow.forward(size)

def draw_dragon4(center, size, counts, colors, angle=0):
    for color, count in zip(colors, counts):
        if color is not None:
            arrow = Arrow(center)
            arrow.pen.color = Color(color)
            arrow.penDown()
            arrow.draw(win)
            arrow.rotate(angle + 45)
            dragon(arrow, count, size)
            arrow.penUp()
            arrow.undraw()
        angle += 90

def makePicture(size):
    global win
    size2 = size / 2

    win = Window(size, size)
    bg = "white"
    win.setBackground(Color(bg))
    win.Hide()

    blue = Color(36, 136, 192)
    yellow = Color(255, 199, 0)

    darkblue = Color(35, 115, 160)
    darkyellow = Color(211, 166, 0)

    angle = -90
    # Shadow:
    if size > 128:
        scolor = darkblue
        yscolor = darkyellow
        draw_dragon4((size2 - 0, size2 + 2), size2, [16] * 4, [None, scolor, None, yscolor], angle)
        draw_dragon4((size2 + 2, size2 - 0), size2, [16] * 4, [None, scolor, None, yscolor], angle)
        draw_dragon4((size2 - 2, size2 + 0), size2, [16] * 4, [None, scolor, None, yscolor], angle)
        draw_dragon4((size2 + 0, size2 - 2), size2, [16] * 4, [None, scolor, None, yscolor], angle)

    draw_dragon4((size2, size2), size2, [16] * 4, [None, blue, None, None], angle)
    draw_dragon4((size2, size2), size2, [16] * 4, [None, None, None, yellow], angle)

    pic = Picture(win)
    pic.setTransparent(Color(bg))
    #pic.flipHorizontal()
    #show(pic)
    pic.savePicture("logo-%dx%d.png" % (size, size))
    return pic



for size in [32, 64]: # 16, 32, 64, 128, 256, 512]:
    pic = makePicture(size)
    show(pic, "%sx%s" % (size, size))
    #pic.savePicture("metakernel-logo-%sx%s.gif" % (size, size))
    #pic.savePicture("metakernel-logo-%sx%s.jpg" % (size, size))



from __future__ import print_function
import sys

from metakernel_python import MetaKernelPython

kernel = MetaKernelPython()

path = "metakernel/magics/README.md"

with open(path) as fid:
    prev = fid.read()

print("Generating README.md...")
prefix = kernel.magic_prefixes['magic']
text = "# Line Magics\n\n"
for magic in sorted(kernel.line_magics.keys()):
    text += "## `" + prefix + magic + "`\n\n"
    text += kernel.get_help_on(prefix + magic) + "\n\n"

text += "# Cell Magics\n\n"
for magic in sorted(kernel.cell_magics.keys()):
    text += "## `" + prefix + prefix + magic + "`\n\n"
    text += kernel.get_help_on(prefix + prefix + magic) + "\n\n"

with open(path, 'w') as fid:
    fid.write(text)

print("done!")

if text != prev:
    print('Readme changed, please commit the changes')
    print('If this is on Travis, run `make help` locally to regenerate')
    sys.exit(1)



from __future__ import print_function

from metakernel import MetaKernel
import sys

class MetaKernelPython(MetaKernel):
    implementation = 'MetaKernel Python'
    implementation_version = '1.0'
    language = 'python'
    language_version = '0.1'
    banner = "MetaKernel Python - evaluates Python statements and expressions"
    language_info = {
        'mimetype': 'text/x-python',
        'name': 'python',
        # ------ If different from 'language':
        # 'codemirror_mode': {
        #    "version": 2,
        #    "name": "ipython"
        # }
        # 'pygments_lexer': 'language',
        # 'version'       : "x.y.z",
        'file_extension': '.py',
        'help_links': MetaKernel.help_links,
    }
    kernel_json = {
        "argv": [
            sys.executable, "-m", "metakernel_python", "-f", "{connection_file}"],
        "display_name": "MetaKernel Python",
        "language": "python",
        "name": "metakernel_python"
    }

    def get_usage(self):
        return ("This is MetaKernel Python. It implements a Python " +
                "interpreter.")

    def set_variable(self, name, value):
        """
        Set a variable in the kernel language.
        """
        python_magic = self.line_magics['python']
        python_magic.env[name] = value

    def get_variable(self, name):
        """
        Get a variable from the kernel language.
        """
        python_magic = self.line_magics['python']
        return python_magic.env.get(name, None)

    def do_execute_direct(self, code):
        python_magic = self.line_magics['python']
        return python_magic.eval(code.strip())

    def get_completions(self, info):
        python_magic = self.line_magics['python']
        return python_magic.get_completions(info)

    def get_kernel_help_on(self, info, level=0, none_on_fail=False):
        python_magic = self.line_magics['python']
        return python_magic.get_help_on(info, level, none_on_fail)


if __name__ == '__main__':
    MetaKernelPython.run_as_main()



import io
import sys

from setuptools import find_packages, setup

PY2 = (sys.version_info[0] == 2)

with io.open('metakernel/__init__.py', encoding='utf-8') as fid:
    for line in fid:
        if line.startswith('__version__'):
            version = line.strip().split()[-1][1:-1]
            break

if PY2:
    ipykernel_requires = "ipykernel (< 6.0)"
    ipykernel_install_requires = "ipykernel<6.0"
else:
    ipykernel_requires = "ipykernel"
    ipykernel_install_requires = "ipykernel"

setup(name='metakernel',
      version=version,
      description='Metakernel for Jupyter',
      long_description=open('README.rst', 'rb').read().decode('utf-8'),
      long_description_content_type='text/x-rst',
      author='Steven Silvester',
      author_email='steven.silvester@ieee.org',
      url='https://github.com/Calysto/metakernel',
      requires=[ipykernel_requires, 'pexpect (>= 4.2)'],
      install_requires=[ipykernel_install_requires, 'pexpect>=4.2'],
      extras_require={
          'activity': ['portalocker'],  # activity magic
          'parallel': ['ipyparallel'],  # parallel magic
          'test': ['pytest', 'pytest-cov', 'requests']
      },
      packages=find_packages(include=['metakernel', 'metakernel.*']),
      package_data={'metakernel': ['images/*.png']},
      python_requires='>=3.5',
      classifiers=[
          'Framework :: IPython',
          'License :: OSI Approved :: BSD License',
          'Programming Language :: Python :: 3',
          'Topic :: System :: Shells',
      ]
      )



from __future__ import print_function

from metakernel import MetaKernel
import sys


class MetaKernelEcho(MetaKernel):
    implementation = 'MetaKernel Echo'
    implementation_version = '1.0'
    language = 'text'
    language_version = '0.1'
    banner = "MetaKernel Echo - as useful as a parrot"
    language_info = {
        'mimetype': 'text/plain',
        'name': 'text',
        # ------ If different from 'language':
        # 'codemirror_mode': {
        #    "version": 2,
        #    "name": "ipython"
        # }
        # 'pygments_lexer': 'language',
        # 'version'       : "x.y.z",
        'file_extension': '.txt',
        'help_links': MetaKernel.help_links,
    }
    kernel_json = {
        'argv': [
            sys.executable, '-m', 'metakernel_echo', '-f', '{connection_file}'],
        'display_name': 'MetaKernel Echo',
        'language': 'echo',
        'name': 'metakernel_echo'
    }

    def get_usage(self):
        return "This is the echo kernel."

    def do_execute_direct(self, code):
        return code.rstrip()

    def repr(self, data):
        return repr(data)


if __name__ == '__main__':
    MetaKernelEcho.run_as_main()
